%global python3_pkgversion 3.11
%global __python3 /usr/bin/python3.11
%{?scl:%scl_package python-%{modname}}
%{!?scl:%global pkg_name %{name}}

%global modname iniparse

# Use the same directory of the main package for subpackage licence and docs
%global _docdir_fmt %{pkg_name}

Name:           %{?scl_prefix}python-%{modname}
Version:        0.4
Release:        39%{?dist}
Summary:        Python Module for Accessing and Modifying Configuration Data in INI files
License:        MIT and Python
URL:            https://pypi.org/project/iniparse/
Source0:        https://files.pythonhosted.org/packages/0f/d1/3090ef9be165da5ddb1b0cf2b332d3282588bdd2dd0967e94b547f10055f/%{modname}-%{version}.tar.gz
Patch0:         0001-Fix-handling-of-REM-xxxxxxxx-as-a-comment-but-REMXXX.patch
# The patch upstream (http://code.google.com/p/iniparse/issues/detail?id=22)
# is Python3-only. The patch below uses python-six to create a version that works
# with both Python major versions and is more error-prone.
Patch1:         0002-python3-compat.patch
# Fixup the module to have proper setup.py information
Patch2:         0003-Fixup-the-module-to-have-proper-setup.py-information.patch

BuildArch: noarch

%global _description \
iniparse is an INI parser for Python which is API compatible\
with the standard library's ConfigParser, preserves structure of INI\
files (order of sections & options, indentation, comments, and blank\
lines are preserved when data is updated), and is more convenient to\
use.


%description %{_description}

%package -n %{?scl_prefix}python%{python3_pkgversion}-%{modname}
Summary:        %{summary}
%{?python_provide:%python_provide python%{python3_pkgversion}-%{modname}}
BuildRequires:  %{?scl_prefix}python%{python3_pkgversion}-devel
BuildRequires:  %{?scl_prefix}python%{python3_pkgversion}-setuptools
BuildRequires:  %{?scl_prefix}python%{python3_pkgversion}-six
BuildRequires:  %{?scl_prefix}python%{python3_pkgversion}-test
Requires:       %{?scl_prefix}python%{python3_pkgversion}-six
Obsoletes:      %{?scl_prefix}platform-python-%{modname} < %{version}-%{release}


%description -n %{?scl_prefix}python%{python3_pkgversion}-%{modname} %{_description}

Python 3 version.

%prep
%{?scl:scl enable %{scl} - << \EOF}
set -ex
%autosetup -p 1 -n %{modname}-%{version}
chmod -c -x html/index.html
%{?scl:EOF}


%build
%{?scl:scl enable %{scl} - << \EOF}
set -ex
%py3_build
%{?scl:EOF}


%install
%{?scl:scl enable %{scl} - << \EOF}
set -ex
%py3_install
rm -vfr %{buildroot}%{_docdir}/*
%{?scl:EOF}


%check
%{?scl:scl enable %{scl} - << \EOF}
set -ex
%{__python3} runtests.py
%{?scl:EOF}


%files -n %{?scl_prefix}python%{python3_pkgversion}-%{modname}
%license LICENSE LICENSE-PSF
%doc README Changelog html/
%{python3_sitelib}/%{modname}/
%{python3_sitelib}/%{modname}-%{version}-*.egg-info


%changelog
* Thu Dec 14 2023 Odilon Sousa <osousa@redhat.com> - 0.4-39
- Dont obsolete python-iniparse

* Thu Nov 23 2023 Odilon Sousa <osousa@redhat.com> - 0.4-38
- Update Patches and change to %autosetup instead of %setup with manual patches

* Tue Nov 21 2023 Patrick Creech <pcreech@redhat.com> - 0.4-37
- Add python39 obsoletes to package

* Sat Nov 11 2023 Odilon Sousa <osousa@redhat.com> - 0.4-36
- Build against python 3.11

* Fri Apr 22 2022 Yanis Guenane <yguenane@redhat.com> - 0.4-35
- Build against python 3.9

* Thu Oct 14 2021 Evgeni Golov - 0.4-34
- Build python-iniparse against Python 3.8
- Rename source back to python-iniparse, as the clash is gone thanks to the SCL

* Mon Jan  4 2021 Evgeni Golov - 0.4-33
- Rename source to python3-iniparse

* Fri Jun 05 2020 Justin Sherrill <jsherril@redhat.com> 0.4-32
- fix python2 requires for el7

* Thu May 02 2019 Adam Price <adprice@redhat.com> - 0.4-31
- rebuilt

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.4-30
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Dec 11 2017 Iryna Shcherbina <ishcherb@redhat.com> - 0.4-29
- Fix ambiguous Python 2 dependency declarations
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Tue Nov 07 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.4-28
- Use better Obsoletes for platform-python

* Fri Nov 03 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.4-27
- Remove platform-python subpackage

* Thu Aug 10 2017 Miro Hrončok <mhroncok@redhat.com> - 0.4-26
- Add platform-python package
- Add bconds
- Remove %%{?system_python_abi}

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.4-25
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.4-24
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sun Dec 11 2016 Neal Gompa <ngompa13@gmail.com> - 0.4-23
- Add patch to update setup.py to use setuptools and declare install dependencies

* Fri Dec 09 2016 Charalampos Stratakis <cstratak@redhat.com> - 0.4-22
- Rebuild for Python 3.6

* Tue Aug 09 2016 Igor Gnatenko <ignatenko@redhat.com> - 0.4-21
- Cleanups
- Add %%{?system_python_abi}

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-20
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Tue Apr 12 2016 Igor Gnatenko <ignatenko@redhat.com> - 0.4-19
- Make python3 builds conditionally
- Adopt to new packaging guidelines
- Remove setuptools from BRs as it's not needed
- Cleanup spec

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.4-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Oct 14 2015 Robert Kuska <rkuska@redhat.com> - 0.4-17
- Rebuilt for Python3.5 rebuild

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Jul 31 2014 Tom Callaway <spot@fedoraproject.org> - 0.4-15
- fix license handling

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed May 14 2014 Bohuslav Kabrda <bkabrda@redhat.com> - 0.4-13
- Rebuilt for https://fedoraproject.org/wiki/Changes/Python_3.4

* Fri Mar 07 2014 Tim Lauridsen <timlau@fedoraproject.org> - 0.4-12
- added python3-test to buildreq for python3
- run unittest with python3 also

* Fri Mar 07 2014 Tim Lauridsen <timlau@fedoraproject.org> - 0.4-11
- added python-test to buildreq, for unittests

* Fri Mar 07 2014 Tim Lauridsen <timlau@fedoraproject.org> - 0.4-10
- added %%check to run unittests when build
- updated fix-issue-28.patch, so test cases dont fail

* Fri Sep 20 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.4-9
- Introduce python3 subpackage.
- Use %%__python2 instead of %%__python.

* Mon Jul 29 2013 Ville Skyttä <ville.skytta@iki.fi> - 0.4-8
- Install docs to %%{_pkgdocdir} where available.

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-6
- fix for upstream issue 28

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 0.4-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild


* Sat Nov 7 2009 Tim Lauridsen <timlau@fedoraproject.org> - 0.4-1
- Release 0.4

* Sat Nov 7 2009 Tim Lauridsen <timlau@fedoraproject.org> - 0.3.1-2
- removed patch

* Sat Nov 7 2009 Tim Lauridsen <timlau@fedoraproject.org> - 0.3.1-1
- Release 0.3.1
-   Fix empty-line handling bugs introduced in 0.3.0

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Mar 2 2009 Tim Lauridsen <timlau@fedoraproject.org> - 0.3.0-2
- added patch from upstream to fix regrestion :

* Sat Feb 28 2009 Tim Lauridsen <timlau@fedoraproject.org> - 0.3.0-1
- Release 0.3.0
-  Fix handling of continuation lines
-  Fix DEFAULT handling
-  Fix picking/unpickling

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Dec 7 2008 Tim Lauridsen <timlau@fedoraproject.org> - 0.2.4-1
- Release 0.2.4:
-   Updated to work with Python-2.6 (Python-2.4 and 2.5 are still supported)
-   Support for files opened in unicode mode
-   Fixed Python-3.0 compatibility warnings
-   Minor API cleanup
* Fri Nov 28 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 0.2.3-5
- Rebuild for Python 2.6
* Tue Jan 8 2008 Tim Lauridsen <timlau@fedoraproject.org> - 0.2.3-4
- own the %%{_docdir}/python-iniparse-%%{version} directory
* Tue Dec 11 2007 Tim Lauridsen <timlau@fedoraproject.org> - 0.2.3-3
- handle egg-info too
* Tue Dec 11 2007 Tim Lauridsen <timlau@fedoraproject.org> - 0.2.3-2
- removed patch source line
* Tue Dec 11 2007 Tim Lauridsen <timlau@fedoraproject.org> - 0.2.3-1
- Updates to release 0.2.3
- removed empty ini file patch, it is included in 0.2.3
* Mon Nov 19 2007 Tim Lauridsen <timlau@fedoraproject.org> - 0.2.2-2
- Added upstream patch to fix problems with empty ini files.
* Tue Sep 25 2007 Tim Lauridsen <timlau@fedoraproject.org> - 0.2.2-1
- Updated to release 0.2.2
- removed patch to to fix problems with out commented lines, included in upstream source
* Wed Sep 12 2007 Tim Lauridsen <timlau@fedoraproject.org> - 0.2.1-4
- Added some logic to get the right python-setuptools buildrequeres
- based on the fedora version, to make the same spec file useful in
- all fedora releases.
* Mon Sep 10 2007 Tim Lauridsen <timlau@fedoraproject.org> - 0.2.1-3
- Added patch from upstream svn to fix problems with out commented lines.
* Tue Aug 28 2007 Tim Lauridsen <timlau@fedoraproject.org> - 0.2.1-2
- Changed BuildRequires python-setuptools to python-setuptools-devel
* Tue Aug 7 2007 Paramjit Oberoi <param@cs.wisc.edu> - 0.2.1-1
- Release 0.2.1
* Fri Jul 27 2007 Tim Lauridsen <timlau@fedoraproject.org> - 0.2-3
- relocated doc to %%{_docdir}/python-iniparse-%%{version}
* Thu Jul 26 2007 Tim Lauridsen <timlau@fedoraproject.org> - 0.2-2
- changed name from iniparse to python-iniparse
* Tue Jul 17 2007 Tim Lauridsen <timlau@fedoraproject.org> - 0.2-1
- Release 0.2
- Added html/* to %%doc
* Fri Jul 13 2007 Tim Lauridsen <timlau@fedoraproject.org> - 0.1-1
- Initial build.
